package org.artifactory.release.bundle;

import lombok.extern.slf4j.Slf4j;
import org.artifactory.common.config.db.ArtifactoryDbProperties;
import org.artifactory.storage.db.bundle.dao.ArtifactBundlesDao;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Lazy;

import static org.jfrog.storage.DbType.DERBY;

/**
 * A release bundle delete-logic template toggle based on the configured DB type
 *
 * @author Uriah Levy
 */
@Configuration
@Slf4j
public class ReleaseBundleDeleteTemplateFactory {

    @Bean
    @Autowired
    public ReleaseBundleDeleteTemplate getReleaseBundleDeleteTemplate(ArtifactBundlesDao bundlesDao,
            @Lazy InternalReleaseBundleService internalReleaseBundleService, ArtifactoryDbProperties dbProperties) {
        if (DERBY.equals(dbProperties.getDbType())) {
            log.debug("Initializing Derby DB Release Bundle Delete template");
            return new DerbyReleaseBundleDeleteTemplate(internalReleaseBundleService);
        }
        return new GeneralReleaseBundleDeleteTemplate(bundlesDao, internalReleaseBundleService);
    }

}
